@@ -1034,14 +1034,6 @@ static gboolean _xfdashboard_settings_create_builder(XfdashboardSettings *self)
 							priv->widgetEnableUnmappedWindowWorkaround,
 							"active");
 
-	priv->widgetEnableHotkey=GTK_WIDGET(gtk_builder_get_object(priv->builder, "enable-hotkey"));
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->widgetEnableHotkey), DEFAULT_ENABLE_HOTKEY);
-	xfconf_g_property_bind(priv->xfconfChannel,
-							"/enable-hotkey",
-							G_TYPE_BOOLEAN,
-							priv->widgetEnableHotkey,
-							"active");
-
 	priv->widgetScrollEventChangedWorkspace=GTK_WIDGET(gtk_builder_get_object(priv->builder, "scroll-event-changes-workspace"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(priv->widgetScrollEventChangedWorkspace), FALSE);
 	xfconf_g_property_bind(priv->xfconfChannel,
@@ -1260,6 +1252,9 @@ GtkWidget* xfdashboard_settings_create_plug(XfdashboardSettings *self, Window in
 	XfdashboardSettingsPrivate	*priv;
 	GtkWidget					*plug;
 	GObject						*dialogChild;
+#if GTK_CHECK_VERSION(3, 14 ,0)
+	GtkWidget					*dialogParent;
+#endif
 
 	g_return_val_if_fail(XFDASHBOARD_IS_SETTINGS(self), NULL);
 	g_return_val_if_fail(inSocketID, NULL);
@@ -1283,7 +1278,17 @@ GtkWidget* xfdashboard_settings_create_plug(XfdashboardSettings *self, Window in
 
 	/* Create plug widget and reparent dialog object to it */
 	plug=gtk_plug_new(inSocketID);
+#if GTK_CHECK_VERSION(3, 14 ,0)
+	g_object_ref(G_OBJECT(dialogChild));
+
+	dialogParent=gtk_widget_get_parent(GTK_WIDGET(dialogChild));
+	gtk_container_remove(GTK_CONTAINER(dialogParent), GTK_WIDGET(dialogChild));
+	gtk_container_add(GTK_CONTAINER(plug), GTK_WIDGET(dialogChild));
+
+	g_object_unref(G_OBJECT(dialogChild));
+#else
 	gtk_widget_reparent(GTK_WIDGET(dialogChild), plug);
+#endif
 	gtk_widget_show(GTK_WIDGET(dialogChild));
 
 	/* Return widget */
