@@ -346,78 +346,6 @@ ClutterActor* xfdashboard_find_actor_by_name(ClutterActor *inActor, const gchar
 	return(NULL);
 }
 
-/* Get GAppInfo from GarconMenu */
-GAppInfo* xfdashboard_garcon_menu_item_get_app_info(GarconMenuItem *inMenuItem)
-{
-	const gchar				*desktopURI;
-	GError					*error;
-	GAppInfo				*appInfo;
-	const gchar				*name;
-	const gchar				*command;
-	GAppInfoCreateFlags		flags;
-
-	g_return_val_if_fail(GARCON_IS_MENU_ITEM(inMenuItem), NULL);
-
-	error=NULL;
-	appInfo=NULL;
-	name=garcon_menu_item_get_name(inMenuItem);
-
-	/* First try to create a desktop application info from desktop ID of menu element */
-	desktopURI=garcon_menu_item_get_uri(inMenuItem);
-	if(desktopURI)
-	{
-		gchar					*desktopFilename;
-
-		/* Get file name which can be used to create desktop application info from */
-		desktopFilename=g_filename_from_uri(desktopURI, NULL, &error);
-		if(error)
-		{
-			g_warning(_("Could not create desktop application information for menu item '%s' from %s: %s"),
-						name,
-						desktopURI,
-						error->message ? error->message : "unknown error");
-			g_error_free(error);
-		}
-
-		if(desktopFilename)
-		{
-			GDesktopAppInfo		*desktopAppInfo;
-
-			/* Create desktop application info from key file loaded successfully.
-			 * If we got a desktop application info return it.
-			 */
-			desktopAppInfo=g_desktop_app_info_new_from_filename(desktopFilename);
-
-			/* Free allocated resources */
-			g_free(desktopFilename);
-
-			/* Return created desktop application info */
-			return(G_APP_INFO(desktopAppInfo));
-		}
-	}
-
-	/* If we get here creating desktop application info failed so fallback to create a simple application info */
-	g_debug("Creating GDesktopAppInfo for menu item '%s' failed. Using fallback method!", name);
-
-	command=garcon_menu_item_get_command(inMenuItem);
-
-	flags=G_APP_INFO_CREATE_NONE;
-	if(garcon_menu_item_supports_startup_notification(inMenuItem)) flags|=G_APP_INFO_CREATE_SUPPORTS_STARTUP_NOTIFICATION;
-	if(garcon_menu_item_requires_terminal(inMenuItem)) flags|=G_APP_INFO_CREATE_NEEDS_TERMINAL;
-
-	appInfo=g_app_info_create_from_commandline(command, name, flags, &error);
-	if(error)
-	{
-		g_warning(_("Could not create application information for menu item '%s': %s"),
-					name,
-					error->message ? error->message : "unknown error");
-		g_error_free(error);
-	}
-
-	/* Return created desktop application info */
-	return(G_APP_INFO(appInfo));
-}
-
 /* Split a string into a NULL-terminated list of tokens using the delimiters and remove
  * white-spaces at the beginning and end of each token. Empty tokens will not be added.
  * Caller is responsible to free result with g_strfreev() if not NULL.
