@@ -35,6 +35,7 @@
 #include "utils.h"
 #include "focus-manager.h"
 #include "viewpad.h"
+#include "enums.h"
 
 /* Define this class in GObject system */
 G_DEFINE_ABSTRACT_TYPE(XfdashboardView,
@@ -331,9 +332,10 @@ static void xfdashboard_view_class_init(XfdashboardViewClass *klass)
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
 	XfdashboardViewProperties[PROP_FIT_MODE]=
-		g_param_spec_string("fit-mode",
+		g_param_spec_enum("fit-mode",
 							_("Fit mode"),
 							_("Defines if view should be fit into viewpad and its orientation"),
+							XFDASHBOARD_TYPE_FIT_MODE,
 							XFDASHBOARD_FIT_MODE_NONE,
 							G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
