@@ -981,13 +981,11 @@ static gboolean _xfdashboard_windows_view_focusable_set_selection(XfdashboardFoc
 	/* Check that selection is a child of this actor */
 	if(inSelection && !xfdashboard_actor_contains_child_deep(CLUTTER_ACTOR(self), inSelection))
 	{
-		ClutterActor						*parent;
-
-		parent=clutter_actor_get_parent(inSelection);
-		g_warning(_("%s is a child of %s and cannot be selected at %s"),
+		g_warning(_("%s is not a child of %s and cannot be selected"),
 					G_OBJECT_TYPE_NAME(inSelection),
-					parent ? G_OBJECT_TYPE_NAME(parent) : "<nil>",
 					G_OBJECT_TYPE_NAME(self));
+
+		return(FALSE);
 	}
 
 	/* Set new selection */
